@@ -1,12 +1,8 @@
 # -*- coding: utf-8 -*-
 
-
 import collections
-import json
 import os
 import re
-import shutil
-import sys
 import subprocess
 import zipfile
 
@@ -17,11 +13,17 @@ from sqlalchemy.exc import SQLAlchemyError
 
 from pychess.Utils.const import NORMALCHESS, RUNNING, DRAW, WHITEWON, BLACKWON
 from pychess.Variants import name2variant
+from pychess.System.Log import log
 from pychess.System import download_file
-from pychess.System.protoopen import protoopen, protosave
+from pychess.System.protoopen import protoopen, protosave, PGN_ENCODING
 from pychess.Database.model import event, site, player, game, annotator, tag_game, source
 # from pychess.System import profile_me
 
+# Editable (on game info dialog) tags
+dedicated_tags = ('Event', 'Site', 'Date', 'Round', 'White', 'Black', 'WhiteElo', 'BlackElo')
+
+# Other tags stored in game table
+other_game_tags = ('Result', 'SetUp', 'FEN', 'ECO', 'Variant', 'PlyCount', 'Annotator', 'offset', 'offset8')
 
 TAG_REGEX = re.compile(r"\[([a-zA-Z0-9_]+)\s+\"(.*)\"\]")
 
@@ -43,12 +45,6 @@ pgn2Const = {"*": RUNNING,
              "0-1": BLACKWON}
 
 
-this_dir = os.path.dirname(os.path.abspath(__file__))
-external = os.path.join(this_dir, "..", "external")
-executable = "pgnextractor.exe" if sys.platform == "win32" else "pgnextractor"
-pgnextractor = shutil.which(executable, mode=os.X_OK, path=external)
-
-
 class PgnImport():
     def __init__(self, chessfile, append_pgn=False):
         self.chessfile = chessfile
@@ -156,7 +152,7 @@ class PgnImport():
         orig_filename = filename
         count_source = self.conn.execute(self.count_source.where(source.c.name == orig_filename)).scalar()
         if count_source > 0:
-            print("%s is already imported" % filename)
+            log.info("%s is already imported" % filename)
             return
 
         # collect new names not in they dict yet
@@ -176,7 +172,7 @@ class PgnImport():
                 return
         else:
             if not os.path.isfile(filename):
-                print("Can't open %s" % filename)
+                log.info("Can't open %s" % filename)
                 return
 
         if filename.lower().endswith(".zip") and zipfile.is_zipfile(filename):
@@ -194,7 +190,7 @@ class PgnImport():
             if progressbar is not None:
                 GLib.idle_add(progressbar.set_text, _("Reading %s ..." % basename))
             else:
-                print("Reading %s ..." % pgnfile)
+                log.info("Reading %s ..." % pgnfile)
 
             size = os.path.getsize(pgnfile)
             handle = protoopen(pgnfile)
@@ -202,19 +198,6 @@ class PgnImport():
             # estimated game count
             all_games = max(size / 840, 1)
 
-            handle_json = None
-            if pgnextractor is not None:
-                try:
-                    headers_json = os.path.splitext(pgnfile)[0] + ".headers.json"
-                    if not os.path.isfile(headers_json):
-                        output = subprocess.check_output([pgnextractor, "headers", pgnfile]).decode()
-                        for line in output:
-                            if line.startswith("Games"):
-                                all_games = line.split()[1]
-                    handle_json = protoopen(headers_json)
-                except subprocess.CalledProcessError:
-                    print("pgnextractor failed")
-
             get_id = self.get_id
 
             # use transaction to avoid autocommit slowness
@@ -222,18 +205,18 @@ class PgnImport():
             trans = self.conn.begin()
             try:
                 i = 0
-                for tags in read_games(handle, handle_json):
+                for tags in read_games(handle):
                     if not tags:
-                        print("Empty game #%s" % (i + 1))
+                        log.info("Empty game #%s" % (i + 1))
                         continue
 
                     if self.cancel:
                         trans.rollback()
                         return
 
-                    fenstr = tags["FEN"] if "FEN" in tags else ""
+                    fenstr = tags["FEN"]
 
-                    variant = tags["Variant"] if "Variant" in tags else ""
+                    variant = tags["Variant"]
                     if variant:
                         if "fischer" in variant.lower() or "960" in variant:
                             variant = "Fischerandom"
@@ -252,7 +235,7 @@ class PgnImport():
 
                     if variant:
                         if variant not in name2variant:
-                            print("Unknown variant: %s" % variant)
+                            log.info("Unknown variant: %s" % variant)
                             continue
                         variant = name2variant[variant].variant
                         if variant == NORMALCHESS:
@@ -262,70 +245,44 @@ class PgnImport():
                         variant = 0
 
                     if basename == "eco.pgn":
-                        white = tags["Opening"] if "Opening" in tags else ""
-                        black = tags["Variation"] if "Variation" in tags else ""
+                        white = tags["Opening"]
+                        black = tags["Variation"]
                     else:
-                        white = tags["White"] if "White" in tags else ""
-                        if white == "":
-                            white = "?"
-                        black = tags["Black"] if "Black" in tags else ""
-                        if black == "":
-                            black = "?"
+                        white = tags["White"]
+                        black = tags["Black"]
 
-                    event_id = get_id(tags["Event"] if "Event" in tags else "", event, EVENT)
+                    event_id = get_id(tags["Event"], event, EVENT)
 
-                    site_id = get_id(tags["Site"] if "Site" in tags else "", site, SITE)
+                    site_id = get_id(tags["Site"], site, SITE)
 
-                    game_date = tags["Date"] if "Date" in tags else ""
-                    try:
-                        if game_date and '?' not in game_date:
-                            ymd = game_date.split('.')
-                            if len(ymd) == 3:
-                                game_year, game_month, game_day = map(int, ymd)
-                            else:
-                                game_year, game_month, game_day = int(game_date[:4]), None, None
-                        elif game_date and '?' not in game_date[:4]:
-                            game_year, game_month, game_day = int(game_date[:4]), None, None
-                        else:
-                            game_year, game_month, game_day = None, None, None
-                    except (ValueError, IndexError):
-                        game_year, game_month, game_day = None, None, None
+                    date = tags["Date"]
 
-                    game_round = tags['Round'] if "Round" in tags else ""
+                    game_round = tags['Round']
 
                     white_id = get_id(white, player, PLAYER)
                     black_id = get_id(black, player, PLAYER)
 
-                    result = tags["Result"] if "Result" in tags else ""
+                    result = tags["Result"]
                     if result in pgn2Const:
                         result = pgn2Const[result]
                     else:
-                        if basename == "eco.pgn":
-                            result = RUNNING
-                        else:
-                            print("Invalid Result tag in game #%s: %s" % (i + 1, result))
-                            continue
+                        result = RUNNING
 
-                    white_elo = tags['WhiteElo'] if "WhiteElo" in tags else "0"
-                    white_elo = int(white_elo) if white_elo and white_elo.isdigit() else 0
+                    white_elo = tags['WhiteElo']
+                    black_elo = tags['BlackElo']
 
-                    black_elo = tags['BlackElo'] if "BlackElo" in tags else ""
-                    black_elo = int(black_elo) if black_elo and black_elo.isdigit() else 0
+                    time_control = tags["TimeControl"]
 
-                    time_control = tags["TimeControl"] if "TimeControl" in tags else ""
+                    eco = tags["ECO"][:3]
 
-                    eco = tags["ECO"][:3] if "ECO" in tags else ""
-
-                    fen = tags["FEN"] if "FEN" in tags else ""
+                    fen = tags["FEN"]
 
                     board_tag = int(tags["Board"]) if "Board" in tags else 0
 
-                    annotator_id = get_id(tags["Annotator"] if "Annotator" in tags else "", annotator, ANNOTATOR)
+                    annotator_id = get_id(tags["Annotator"], annotator, ANNOTATOR)
 
                     source_id = get_id(orig_filename, source, SOURCE, info=info)
 
-                    self.next_id[GAME] += 1
-
                     ply_count = tags["PlyCount"] if "PlyCount" in tags else 0
 
                     offset = base_offset + int(tags["offset"])
@@ -335,9 +292,7 @@ class PgnImport():
                         'offset8': (offset >> 3) << 3,
                         'event_id': event_id,
                         'site_id': site_id,
-                        'date_year': game_year,
-                        'date_month': game_month,
-                        'date_day': game_day,
+                        'date': date,
                         'round': game_round,
                         'white_id': white_id,
                         'black_id': black_id,
@@ -354,6 +309,15 @@ class PgnImport():
                         'source_id': source_id,
                     })
 
+                    for tag in tags:
+                        if tag not in dedicated_tags and tag not in other_game_tags and tags[tag]:
+                            self.tag_game_data.append({
+                                'game_id': self.next_id[GAME],
+                                'tag_name': tag,
+                                'tag_value': tags[tag],
+                            })
+
+                    self.next_id[GAME] += 1
                     i += 1
 
                     if len(self.game_data) >= self.CHUNK:
@@ -379,6 +343,10 @@ class PgnImport():
                             self.conn.execute(self.ins_source, self.source_data)
                             self.source_data = []
 
+                        if self.tag_game_data:
+                            self.conn.execute(self.ins_tag_game, self.tag_game_data)
+                            self.tag_game_data = []
+
                         self.conn.execute(self.ins_game, self.game_data)
                         self.game_data = []
 
@@ -387,7 +355,7 @@ class PgnImport():
                             GLib.idle_add(progressbar.set_text, _(
                                 "%(counter)s game headers from %(filename)s imported" % ({"counter": i, "filename": basename})))
                         else:
-                            print(pgnfile, i)
+                            log.info("From %s imported %s" % (pgnfile, i))
 
                 if self.event_data:
                     self.conn.execute(self.ins_event, self.event_data)
@@ -409,6 +377,10 @@ class PgnImport():
                     self.conn.execute(self.ins_source, self.source_data)
                     self.source_data = []
 
+                if self.tag_game_data:
+                    self.conn.execute(self.ins_tag_game, self.tag_game_data)
+                    self.tag_game_data = []
+
                 if self.game_data:
                     self.conn.execute(self.ins_game, self.game_data)
                     self.game_data = []
@@ -418,7 +390,7 @@ class PgnImport():
                     GLib.idle_add(progressbar.set_text, _(
                         "%(counter)s game headers from %(filename)s imported" % ({"counter": i, "filename": basename})))
                 else:
-                    print(pgnfile, i)
+                    log.info("From %s imported %s" % (pgnfile, i))
                 trans.commit()
 
                 if self.append_pgn:
@@ -426,7 +398,7 @@ class PgnImport():
                     self.db_handle.close()
                     self.db_handle = protosave(self.chessfile.path, self.append_pgn)
 
-                    print("Append from %s to %s" % (pgnfile, self.chessfile.path))
+                    log.info("Append from %s to %s" % (pgnfile, self.chessfile.path))
                     handle.seek(0)
                     self.db_handle.writelines(handle)
                     self.db_handle.close()
@@ -450,53 +422,12 @@ class PgnImport():
 
             except SQLAlchemyError as e:
                 trans.rollback()
-                print("Importing %s failed! \n%s" % (pgnfile, e))
+                log.info("Importing %s failed! \n%s" % (pgnfile, e))
 
 
-def read_games(handle, handle_json=None):
+def read_games(handle):
     """Based on chess.pgn.scan_headers() from Niklas Fiekas python-chess"""
 
-    if handle_json is not None:
-        for line in handle_json:
-            try:
-                yield json.loads(line)
-            except ValueError as e:
-                try:
-                    if "\\" in line:
-                        line = line.replace("\\", "")
-                        yield json.loads(line)
-                    elif e.message.startswith("Expecting ',' delimiter"):
-                        if '"Date":' in line and '"Site":' in line and '"Event":' in line:
-                            left, date = line.split(', "Date":')
-                            left, site = left.split(', "Site":')
-                            left, event = left.split('"Event":')
-                            event = event.replace('"', '')
-                            site = site.replace('"', '')
-                            line = '{"Event":"%s", "Site":"%s", "Date":%s' % (event, site, date)
-                            yield json.loads(line)
-                        else:
-                            continue
-                    elif e.message.startswith("Invalid control character"):
-                        stripped = []
-                        for char in line:
-                            if ord(char) >= 32:
-                                stripped.append(char)
-                        line = "".join(stripped)
-                        yield json.loads(line)
-                    elif e.message.startswith("No JSON object could be decoded"):
-                        if line.startswith("[Date"):
-                            line = line.replace("[Date", '{"Date')
-                            yield json.loads(line)
-                        else:
-                            continue
-                    else:
-                        continue
-                except ValueError:
-                    continue
-            except ValueError:
-                continue
-        return
-
     in_comment = False
 
     game_headers = None
@@ -523,7 +454,13 @@ def read_games(handle, handle_json=None):
                     game_headers = collections.defaultdict(str)
                     game_pos = last_pos
 
-                game_headers[tag_match.group(1)] = tag_match.group(2)
+                tag_value = tag_match.group(2)
+                tag_value = tag_value.replace("\\\"", "\"")
+                tag_value = tag_value.replace("\\\\", "\\")
+
+                if handle.pgn_encoding != PGN_ENCODING:
+                    tag_value = tag_value.encode(PGN_ENCODING).decode(handle.pgn_encoding)
+                game_headers[tag_match.group(1)] = tag_value
 
                 last_pos += len(line)
                 line = handle.readline()
