@@ -12,10 +12,7 @@ import textwrap
 
 from gi.repository import GLib
 
-try:
-    import pexpect
-except ImportError:
-    from pychess.external import pexpect
+import pexpect
 
 from sqlalchemy import String
 
@@ -127,7 +124,7 @@ def parseTimeControlTag(tag):
             return None
 
 
-def save(handle, model, position=None):
+def save(handle, model, position=None, flip=False):
     """ Saves the game from GameModel to .pgn """
     processed_tags = []
 
