@@ -13,7 +13,7 @@ def load_icon(size, *alternatives):
     name = alternatives.pop(0)
     try:
         return it.load_icon(name, size, Gtk.IconLookupFlags.USE_BUILTIN)
-    except:
+    except Exception:
         if alternatives:
             return load_icon(size, *alternatives)
         log.warning("no %s icon in icon-theme-gnome" % name)
