@@ -1,4 +1,3 @@
-
 from .bitboard import bitPosArray, iterBits, clearBit, firstBit
 from .attack import isAttacked, pinnedOnKing, getAttacks
 from .ldata import fromToRay, moveArray, directions, fileBits, rankBits,\
@@ -189,9 +188,31 @@ def genPieceMoves(board, piece, tcord):
     return moves
 
 
+def gen_sittuyin_promotions(board):
+    from pychess.Variants import variants
+    blocker = board.blocker
+    notblocker = ~blocker
+
+    pawns = board.boards[board.color][PAWN]
+
+    queenMoves = moveArray[ASEAN_QUEEN]
+    promotion_zone = variants[SITTUYINCHESS].PROMOTION_ZONE[board.color]
+    for cord in iterBits(pawns):
+        if board.pieceCount[board.color][PAWN] == 1 or cord in promotion_zone:
+            # in place promotions
+            move = newMove(cord, cord, QUEEN_PROMOTION)
+            if not board.willGiveCheck(move):
+                yield move
+
+            # queen move promotion
+            for c in iterBits(queenMoves[cord] & notblocker):
+                move = newMove(cord, c, QUEEN_PROMOTION)
+                if not board.willGiveCheck(move):
+                    yield move
+
+
 def genAllMoves(board, drops=True):
     from pychess.Variants import variants
-
     if drops and board.variant in DROP_VARIANTS:
         for move in genDrops(board):
             yield move
@@ -217,6 +238,7 @@ def genAllMoves(board, drops=True):
     kings = board.boards[board.color][KING]
 
     PROMOTIONS = variants[board.variant].PROMOTIONS
+    # In sittuyin only one queen allowed to exist any time per side
     if board.variant == SITTUYINCHESS and queens:
         PROMOTIONS = (NORMAL_MOVE, )
 
@@ -289,7 +311,10 @@ def genAllMoves(board, drops=True):
 
         # One step
 
-        promotion_zone = variants[board.variant].PROMOTION_ZONE[WHITE]
+        if board.variant == SITTUYINCHESS:
+            promotion_zone = []
+        else:
+            promotion_zone = variants[board.variant].PROMOTION_ZONE[WHITE]
         movedpawns = (pawns >>
                       8) & notblocker  # Move all pawns one step forward
         for cord in iterBits(movedpawns):
@@ -350,7 +375,10 @@ def genAllMoves(board, drops=True):
 
         # One step
 
-        promotion_zone = variants[board.variant].PROMOTION_ZONE[BLACK]
+        if board.variant == SITTUYINCHESS:
+            promotion_zone = []
+        else:
+            promotion_zone = variants[board.variant].PROMOTION_ZONE[BLACK]
         movedpawns = (pawns << 8) & notblocker
         movedpawns &= 0xffffffffffffffff  # contrain to 64 bits
         for cord in iterBits(movedpawns):
@@ -395,11 +423,10 @@ def genAllMoves(board, drops=True):
             else:
                 yield newMove(cord + 9, cord)
 
-    # Sittuyin in place promotions
+    # Sittuyin promotions
     if board.variant == SITTUYINCHESS and pawns and not queens:
-        for cord in iterBits(pawns):
-            if cord in promotion_zone:
-                yield newMove(cord, cord, QUEEN_PROMOTION)
+        for move in gen_sittuyin_promotions(board):
+            yield move
 
     # Cambodian extra first moves for king and queen
     if board.variant == CAMBODIANCHESS:
@@ -450,7 +477,8 @@ def genCaptures(board):
     kings = board.boards[board.color][KING]
 
     PROMOTIONS = variants[board.variant].PROMOTIONS
-    if board.variant == SITTUYINCHESS and queens:
+    # In sittuyin promotion can't give capture
+    if board.variant == SITTUYINCHESS:
         PROMOTIONS = (NORMAL_MOVE, )
 
     # Knights
@@ -588,12 +616,14 @@ def genCheckEvasions(board):
     kcord = board.kings[color]
     kings = board.boards[color][KING]
     pawns = board.boards[color][PAWN]
+    queens = board.boards[board.color][QUEEN]
     checkers = getAttacks(board, kcord, opcolor)
 
     arBoard = board.arBoard
     if bin(checkers).count("1") == 1:
 
         PROMOTIONS = variants[board.variant].PROMOTIONS
+        # In sittuyin promotion move not allowed to capture opponent pieces
         if board.variant == SITTUYINCHESS and board.boards[board.color][QUEEN]:
             PROMOTIONS = (NORMAL_MOVE, )
         promotion_zone = variants[board.variant].PROMOTION_ZONE[color]
@@ -603,7 +633,7 @@ def genCheckEvasions(board):
         b = getAttacks(board, chkcord, color) & ~kings
         for cord in iterBits(b):
             if not pinnedOnKing(board, cord, color):
-                if arBoard[cord] == PAWN and chkcord in promotion_zone:
+                if arBoard[cord] == PAWN and chkcord in promotion_zone and board.variant != SITTUYINCHESS:
                     for p in PROMOTIONS:
                         yield newMove(cord, chkcord, p)
                 else:
@@ -660,6 +690,12 @@ def genCheckEvasions(board):
                                     continue
                             yield newMove(piece, cord, DROP)
 
+                if board.variant == SITTUYINCHESS and pawns and not queens:
+                    from .lmove import TCORD
+                    for move in gen_sittuyin_promotions(board):
+                        if TCORD(move) == cord:
+                            yield move
+
     # If more than one checkers, move king to get out of check
     if checkers:
         escapes = moveArray[KING][kcord] & ~board.friends[color]
@@ -689,14 +725,12 @@ def genDrops(board):
                         if color == WHITE:
                             if cord in (A3, B3, C3, D3) or cord > H3:
                                 continue
-                            if piece == ROOK and cord > H1 or \
-                               piece != ROOK and cord <= H1:
+                            if piece == ROOK and cord > H1:
                                 continue
                         else:
                             if cord in (E6, F6, G6, H6) or cord < A6:
                                 continue
-                            if piece == ROOK and cord < A8 or \
-                               piece != ROOK and cord >= A8:
+                            if piece == ROOK and cord < A8:
                                 continue
 
                     elif board.variant == PLACEMENTCHESS:
