@@ -8,7 +8,7 @@ from pychess.Utils.Offer import Offer
 from pychess.Utils.const import REMOTE, DRAW, WHITE, BLACK, RUNNING, WHITEWON, KILLED, \
     TAKEBACK_OFFER, WAITING_TO_START, BLACKWON, PAUSE_OFFER, PAUSED, \
     RESUME_OFFER, DISCONNECTED, CHAT_ACTION, RESIGNATION, FLAG_CALL, OFFERS, LOCAL, \
-    UNFINISHED_STATES, ABORT_OFFER
+    UNFINISHED_STATES, ABORT_OFFER, ACTION_ERROR_NONE_TO_ACCEPT
 from pychess.Players.Human import Human
 from pychess.Savers import fen as fen_loader
 from pychess.ic import GAME_TYPES, TYPE_TOURNAMENT_DIRECTOR
@@ -350,9 +350,14 @@ class ICGameModel(GameModel):
         log.debug("ICGameModel.acceptReceived: accepter=%s %s" %
                   (repr(player), offer))
         if player.__type__ == LOCAL:
-            GameModel.acceptReceived(self, player, offer)
-            log.debug("ICGameModel.acceptReceived: connection.om.accept(%s)" % offer)
-            self.connection.om.accept(offer)
+            if offer not in self.offers or self.offers[offer] == player:
+                player.offerError(offer, ACTION_ERROR_NONE_TO_ACCEPT)
+            else:
+                log.debug(
+                    "ICGameModel.acceptReceived: connection.om.accept(%s)" %
+                    offer)
+                self.connection.om.accept(offer)
+                del self.offers[offer]
 
         # We don't handle any ServerPlayer calls here, as the fics server will
         # know automatically if he/she accepts an offer, and will simply send
