@@ -165,7 +165,7 @@ class Games(GObject.GObject, Perspective):
                     player.setOptionInitialBoard(gamemodel)
             log.debug("Games..generalStart: -> gamemodel.start(): %s" %
                       (gamemodel))
-
+            gamemodel.emit("game_loaded", "")
             gamemodel.start()
             log.debug("Games.generalStart: <- gamemodel.start(): %s" %
                       (gamemodel))
@@ -258,8 +258,8 @@ class Games(GObject.GObject, Perspective):
         title = _("Save Game") if not export else _("Export position")
         savedialog.set_title(title)
         while True:
-            savedialog.set_current_name(
-                "%s %s %s" % (game.players[0], _("vs."), game.players[1]))
+            filename = "%s-%s" % (game.players[0], game.players[1])
+            savedialog.set_current_name(filename.replace(" ", "_"))
 
             res = savedialog.run()
             if res != Gtk.ResponseType.ACCEPT:
