@@ -5,7 +5,6 @@ from gi.repository import Gtk, Gdk, Pango, GObject
 
 from pychess.System import uistuff
 from pychess.widgets import insert_formatted
-from pychess.widgets.Background import set_textview_color
 from pychess.Utils.IconLoader import load_icon
 from pychess.ic.ICGameModel import ICGameModel
 
@@ -27,7 +26,6 @@ class ChatView(Gtk.Box):
 
         # Inits the read view
         self.readView = Gtk.TextView()
-        set_textview_color(self.readView)
 
         self.sw = Gtk.ScrolledWindow()
         self.sw.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
@@ -56,7 +54,6 @@ class ChatView(Gtk.Box):
             # Inits the observers view
             self.obsView = Gtk.TextView()
             self.obsView.set_cursor_visible(False)
-            set_textview_color(self.obsView)
 
             self.obsView.set_editable(False)
             self.obsView.props.wrap_mode = Gtk.WrapMode.WORD
@@ -72,7 +69,7 @@ class ChatView(Gtk.Box):
             text_buffer.insert_with_tags_by_name(iter, " ", "observers")
             text_buffer.insert(iter, "\n")
 
-            if not self.gamemodel.connection.offline_lecture:
+            if not self.gamemodel.offline_lecture:
                 vbox.pack_start(self.obsView, False, True, 0)
             vbox.pack_start(self.sw, True, True, 0)
 
@@ -93,20 +90,19 @@ class ChatView(Gtk.Box):
         self.pack_start(self.writeView, False, False, 0)
         box.add(self.writeView)
 
-        if isinstance(self.gamemodel, ICGameModel) and \
-                self.gamemodel.connection.offline_lecture:
+        if self.gamemodel is not None and self.gamemodel.offline_lecture:
             label = _("Go on")
             self.go_on_btn = Gtk.Button()
             self.go_on_btn.set_label(label)
             self.go_on_btn_cid = self.go_on_btn.connect(
-                "clicked", lambda btn: self.gamemodel.connection.lecture_skip_event.set())
+                "clicked", lambda btn: self.gamemodel.lecture_skip_event.set())
             box.add(self.go_on_btn)
 
             label = _("Pause")
             self.pause_btn = Gtk.Button()
             self.pause_btn.set_label(label)
             self.pause_btn_cid = self.pause_btn.connect(
-                "clicked", lambda btn: self.gamemodel.connection.lecture_pause_event.set())
+                "clicked", lambda btn: self.gamemodel.lecture_pause_event.set())
             box.add(self.pause_btn)
 
         self.pack_start(box, False, False, 0)
